meta_package_manager.tests.test_bitbar_plugin module — Meta Package Manager 2.4.0 documentation

# meta_package_manager.tests.test_bitbar_plugin module

class `meta_package_manager.tests.test_bitbar_plugin.` `TestBitBarPlugin`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_simple_call`()